Job Manager Common
==================

About
-----

This library attempts to provide a Job Manager common library to use with client or api

Project url : https://github.com/ronhanson/python-jobmanager-common


Usage
-----

***Lib Usage***

<BLAH>

Compatibility
-------------

This client can be used on Linux, OSX systems, or Windows.

This libraries are compatibles with Python 2.X and Python 3.X.

Mainly tested on 2.7 and 3.4.


Author & Licence
----------------

Copyright (c) 2007-2015 Ronan Delacroix

This program is released under MIT Licence. Feel free to use it or part of it anywhere you want.
 
